@@ -51,7 +51,7 @@ int main( int argc, char ** argv )
        std::cout << "main: Entered main in debug mode" << std::endl;
 
 #ifdef MAEMO
-    osso_context = osso_initialize("otrplayer", "0.3", FALSE, NULL);
+    osso_context = osso_initialize("otrplayer", "0.4", FALSE, NULL);
     if (osso_context == NULL)
        std::cerr << "Can't initialize osso context." << std::endl;
 #endif
@@ -61,9 +61,6 @@ int main( int argc, char ** argv )
     if (debug)
        std::cout << "main: calling showMainWidget" << std::endl;
 
-#if 0
-    a.showMainWidget( &mw );
-#endif
     mw.show();
 
     ret = a.exec();
