@@ -51,7 +51,7 @@
 using std::list;
 
 
-#define PLAY_DELTA 10240
+#define PLAY_DELTA 1024 * 5
 #define MP3_DATA_CFG "otrplayer.cfg"
 #define FILE_LINE 0
 #define INFO_LINE 1
@@ -165,7 +165,7 @@ otrplayer::about()
       std::cout << "otrplayer: about called" << std::endl;
    QMessageBox::about(this, tr("About Otrplayer"),
       tr("<img src=\"/usr/share/icons/hicolor/scalable/hildon/otrplayer.png\" align=\"middle\" />"
-      "<h1 align=\"center\"><b>Otrplayer 0.3</b></h1>"
+      "<h1 align=\"center\"><b>Otrplayer 0.4</b></h1>"
       "<h5 align=\"center\">OTR Audio Player</h5>"
       "<h5 align=\"center\">(C) 2009 Bruce Forsberg</h5>"
       "<h5 align=\"center\">http://otrplayer.garage.maemo.org</h5>"));
@@ -178,27 +178,27 @@ otrplayer::keyPressEvent(QKeyEvent *e)
    bool action = false;
 
    if (_debug)
-      std::cout << "otrplayer: Pressed key:" << e->key() << std::endl;
+      std::cout << "otrplayer: Pressed key:" << std::hex << e->key() << std::endl;
 
-   // Far left key on the SL-5500 PDA, activity
+   // This is the Plus key on the top of the NOKIA TABLETS
    if (e->key() == Qt::Key_F7)
    {
       if (_debug)
          std::cout << "otrplayer: Key recognized as PLUS" << std::endl;
       action = performKeyEvent(_otr_file->getButton(otrplayerfile::CALENDAR_KEY));
    }
-   // Next left ley on the SL-5500 PDA, contacts
+   // This is the Minus key of the top of the NOKIA TABLETS
    else if (e->key() == Qt::Key_F8)
    {
       if (_debug)
          std::cout << "otrplayer: Key recognized as MINUS" << std::endl;
       action = performKeyEvent(_otr_file->getButton(otrplayerfile::ADDRESS_KEY));
    }
-   // Second far right key of the SL-5500 PDA, Menu
-   else if (e->key() == Qt::Key_F11)
+   // Swap Key on the Nokia Tablets
+   else if (e->key() == Qt::Key_F5)
    {
       if (_debug)
-         std::cout << "otrplayer: Key recognized as MENU" << std::endl;
+         std::cout << "otrplayer: Key recognized as Swap" << std::endl;
       action = performKeyEvent(_otr_file->getButton(otrplayerfile::MENU_KEY));
    }
    // Far right key of the SL-5500 PDA, Mail
@@ -208,7 +208,7 @@ otrplayer::keyPressEvent(QKeyEvent *e)
          std::cout << "otrplayer: Key recognized as EMAIL" << std::endl;
       action = performKeyEvent(_otr_file->getButton(otrplayerfile::EMAIL_KEY));
    }
-   // Cancel Key
+   // Escape Key on the Nokia Tablets
    else if (e->key() == Qt::Key_Escape)
    {
       if (_debug)
@@ -321,15 +321,8 @@ otrplayer::setup(QString& file)
       _pitch->setCacheEnable(FALSE);
       pitchCallback(pitchSlider->value());
 
-#if 0
-      if (_debug)
-         std::cout << "setup: create aflibAudioSampleRateCvt" << std::endl;
-      _sample_rate = new aflibAudioSampleRateCvt(*_input, _sample_rate_conversion_factor);
-      _sample_rate->setCacheEnable(FALSE);
-#endif 
-
        if (_debug)
-          std::cout << "setup: create output aflibAudioFile with rate " << _sample_rate->getOutputConfig().getSamplesPerSecond() << std::endl;
+          std::cout << "setup: create output aflibAudioFile with rate " << _pitch->getOutputConfig().getSamplesPerSecond() << std::endl;
       aflibConfig output_config(_pitch->getOutputConfig());
       _output = new aflibAudioFile(*_pitch, AFLIB_DEV_TYPE, "/dev/dsp",
             &output_config, &status);
@@ -965,7 +958,10 @@ otrplayer::rev()
    {
       str1 = _item->text(DIR_FIELD) + "/" + _item->text(FILE_FIELD);
       if (str == str1)
+      {
          _current_position = 0;
+         _source_current_position = 0;
+      }
    }
 
    secondsToQString(0, str2);
